@@ -450,6 +450,14 @@ handle_set_compress( CDK_HD hd, int algo, int level )
 }
 
 
+/**
+ * cdk_handle_control:
+ * @hd: session handle
+ * @action: flag which indicates whether put or get is requested
+ * @cmd: command id
+ *
+ * Perform various control operations for the current session.
+ **/
 int
 cdk_handle_control( CDK_HD hd, int action, int cmd, ... )
 {
@@ -537,6 +545,13 @@ cdk_handle_control( CDK_HD hd, int action, int cmd, ... )
             val = hd->opt.force_digest;
         break;
 
+    case CDK_CTL_TRUSTMODEL:
+        if( set )
+            hd->trust_model = va_arg( arg_ptr, int );
+        else
+            val = hd->trust_model;
+        break;
+
     default:
         val = -1;
         break;
@@ -605,6 +620,13 @@ cdk_handle_set_keydb( CDK_HD hd, CDK_KEYDB_HD db )
 }
 
 
+/**
+ * cdk_handle_get_keydb:
+ * @hd: session handle
+ * @type: type of the keyring
+ *
+ * Return the keydb handle from the session handle.
+ **/
 CDK_KEYDB_HD
 cdk_handle_get_keydb( CDK_HD hd, int type )
 {
