@@ -1,5 +1,5 @@
 /* misc.c
- *        Copyright (C) 2002 Timo Schulz
+ *        Copyright (C) 2002, 2003 Timo Schulz
  *        Copyright (C) 1998-2002 Free Software Foundation, Inc.
  *
  * This file is part of OpenCDK.
@@ -26,6 +26,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <time.h>
+#include <malloc.h>
 
 #include "opencdk.h"
 #include "main.h"
@@ -573,5 +574,16 @@ vasprintf ( char **result, const char *format, va_list args)
     return 0;
 }
 
-#endif /*__MINGW32__*/
-
+void
+_cdk_vasprintf_free (void * p)
+{
+    cdk_free (p);
+}
+#else /*!__MINGW32__*/
+void
+_cdk_vasprintf_free (void * p)
+{
+    if (p)
+        free (p);
+}
+#endif
