@@ -23,7 +23,7 @@
 
 #include <stdarg.h>
 
-#define OPENCDK_VERSION "0.4.3"
+#define OPENCDK_VERSION "0.4.4"
 
 #ifdef __cplusplus
 extern "C" {
@@ -118,7 +118,8 @@ enum
   CDK_CTL_S2K           = 16,
   CDK_CTL_KEYCACHE_ON   = 17,
   CDK_CTL_KEYCACHE_FREE = 18,
-  CDK_CTL_FORCE_DIGEST  = 19
+  CDK_CTL_FORCE_DIGEST  = 19,
+  CDK_CTL_TRUSTMODEL    = 20
 };
 
 enum
@@ -179,6 +180,14 @@ enum
   CDK_PREFTYPE_ZIP  = 3
 };
 
+enum
+{
+  CDK_REVCOD_NOREASON   = 0x00,
+  CDK_REVCOD_SUPERCEDED = 0x01,
+  CDK_REVCOD_COMPROMISED= 0x02,
+  CDK_REVCOD_NOLONGUSED = 0x03
+};
+
 enum
 {
   CDK_ARMOR_MESSAGE   = 0,
@@ -587,6 +596,8 @@ unsigned long cdk_sk_get_keyid (cdkPKT_secret_key * sk, unsigned long * keyid);
 unsigned long cdk_sig_get_keyid (cdkPKT_signature * sg, unsigned long * keyid);
 int cdk_sk_unprotect (cdkPKT_secret_key * sk, const char * pw);
 int cdk_sk_protect (cdkPKT_secret_key * sk, const char * pw);
+int cdk_pk_from_secret_key( cdkPKT_secret_key * sk,
+                            cdkPKT_public_key ** ret_pk );
 
 /*-- seskey.c --*/
 int cdk_sesskey_new( CDK_SESSKEY * r_sk );
@@ -640,6 +651,8 @@ int cdk_stream_set_compress_flag (CDK_STREAM s, int algo, int level);
 int cdk_stream_set_hash_flag (CDK_STREAM s, int algo);
 int cdk_stream_set_text_flag (CDK_STREAM s, const char * lf);
 int cdk_stream_kick_off (CDK_STREAM inp, CDK_STREAM out);
+int cdk_stream_mmap( CDK_STREAM s, unsigned char ** ret_buf,
+                     size_t * ret_count );
 
 /*-- keydb.c --*/
 int cdk_keydb_new (CDK_KEYDB_HD * r_hd, int type, void * data, size_t count);
@@ -647,21 +660,22 @@ int cdk_keydb_open (CDK_KEYDB_HD hd, CDK_STREAM * ret_kr);
 int cdk_keydb_check_sk( CDK_KEYDB_HD hd, unsigned long * keyid );
 int cdk_keydb_search_new (CDK_DBSEARCH * r_dbs, int type, void * desc);
 void cdk_keydb_search_free (CDK_DBSEARCH dbs);
-int cdk_keydb_search (CDK_KEYDB_HD hd, CDK_DBSEARCH ks, CDK_KBNODE * r_key);
+int cdk_keydb_search (CDK_KEYDB_HD hd, CDK_DBSEARCH ks, CDK_KBNODE * ret_key);
 int cdk_keydb_search_auto (CDK_KEYDB_HD hd, const char *desc,
-                           CDK_KBNODE * r_knode);
+                           CDK_KBNODE * ret_key);
 void cdk_keydb_free (CDK_KEYDB_HD hd);
 int cdk_keydb_get_bykeyid (CDK_KEYDB_HD hd, unsigned long * keyid,
-                           CDK_KBNODE * r_key);
+                           CDK_KBNODE * ret_key);
 int cdk_keydb_get_byfpr (CDK_KEYDB_HD hd, const unsigned char * fpr,
-                         CDK_KBNODE * r_key);
+                         CDK_KBNODE * ret_key);
 int cdk_keydb_get_bypattern (CDK_KEYDB_HD hd, const char * patt,
-                             CDK_KBNODE * r_pkt);
+                             CDK_KBNODE * ret_key);
 int cdk_keydb_get_pk (CDK_KEYDB_HD khd, unsigned long * keyid,
                       cdkPKT_public_key ** ret_pk);
 int cdk_keydb_get_sk (CDK_KEYDB_HD khd, unsigned long * keyid,
                       cdkPKT_secret_key ** ret_sk);
 int cdk_keydb_get_keyblock (CDK_STREAM inp, CDK_KBNODE * ret_key);
+int cdk_keydb_idx_rebuild( CDK_KEYDB_HD hd );
 int cdk_keydb_export (CDK_KEYDB_HD hd, CDK_STREAM out, CDK_STRLIST remusr);
 int cdk_keydb_import (CDK_KEYDB_HD hd, CDK_KBNODE knode, int result[4]);
 
@@ -671,7 +685,7 @@ int cdk_kbnode_read_from_mem (CDK_KBNODE * ret_node,
                              const unsigned char * buf, size_t buflen);
 int cdk_kbnode_write_to_mem (CDK_KBNODE node,
                              unsigned char * buf, size_t * r_nbytes);
-void cdk_kbnode_release (CDK_KBNODE n);
+void cdk_kbnode_release (CDK_KBNODE node);
 CDK_KBNODE cdk_kbnode_walk (CDK_KBNODE root, CDK_KBNODE * ctx, int all);
 CDK_PACKET * cdk_kbnode_find_packet (CDK_KBNODE node, int pkttype);
 CDK_PACKET * cdk_kbnode_get_packet (CDK_KBNODE node);
@@ -743,7 +757,7 @@ char * cdk_utf8_decode (const char * string, size_t length, int delim);
 /*-- keyserver.c --*/
 int cdk_keyserver_recv_key (const char * host, int port,
                             const unsigned char * keyid, int kid_type,
-                            CDK_KBNODE * r_knode);
+                            CDK_KBNODE * r_key);
 
 /*-- keygen.c --*/
 int cdk_keygen_new (CDK_KEYGEN_CTX * r_hd);
