@@ -563,12 +563,12 @@ _cdk_pk_algo_usage( int algo )
     int usage = 0;
 
     switch( algo ) {
-    case GCRY_PK_RSA  : usage = GCRY_PK_USAGE_SIGN | GCRY_PK_USAGE_ENCR; break;
-    case GCRY_PK_RSA_E: usage = GCRY_PK_USAGE_ENCR; break;
-    case GCRY_PK_RSA_S: usage = GCRY_PK_USAGE_SIGN; break;
-    case GCRY_PK_ELG  : usage = GCRY_PK_USAGE_SIGN | GCRY_PK_USAGE_ENCR; break;
-    case GCRY_PK_ELG_E: usage = GCRY_PK_USAGE_ENCR; break;
-    case GCRY_PK_DSA  : usage = GCRY_PK_USAGE_SIGN; break; 
+    case CDK_PK_RSA  : usage = GCRY_PK_USAGE_SIGN | GCRY_PK_USAGE_ENCR; break;
+    case CDK_PK_RSA_E: usage = GCRY_PK_USAGE_ENCR; break;
+    case CDK_PK_RSA_S: usage = GCRY_PK_USAGE_SIGN; break;
+    case CDK_PK_ELG  : usage = GCRY_PK_USAGE_SIGN | GCRY_PK_USAGE_ENCR; break;
+    case CDK_PK_ELG_E: usage = GCRY_PK_USAGE_ENCR; break;
+    case CDK_PK_DSA  : usage = GCRY_PK_USAGE_SIGN; break; 
     }
     return usage;  
 }
@@ -777,7 +777,7 @@ cdk_sk_protect( cdkPKT_secret_key * sk, const char * pass )
     size_t enclen = 0, nskey, i;
     int rc;
 
-    rc = cdk_s2k_new( &s2k, 3, GCRY_MD_SHA1, NULL );
+    rc = cdk_s2k_new( &s2k, 3, CDK_MD_SHA1, NULL );
     if( rc )
         return rc;
     rc = cdk_dek_from_passphrase( &dek, GCRY_CIPHER_3DES, s2k, 2, pass );
@@ -813,7 +813,7 @@ cdk_sk_protect( cdkPKT_secret_key * sk, const char * pass )
         return CDK_Gcry_Error;
     }
 
-    md = gcry_md_open( GCRY_MD_SHA1, GCRY_CIPHER_SECURE  );
+    md = gcry_md_open( CDK_MD_SHA1, GCRY_CIPHER_SECURE  );
     if( !md ) {
         gcry_cipher_close( hd  );
         cdk_free( p  );
@@ -833,6 +833,13 @@ cdk_sk_protect( cdkPKT_secret_key * sk, const char * pass )
 }
 
 
+/**
+ * cdk_pk_from_secret_key:
+ * @sk: the secret key
+ * @ret_pk: the new public key
+ *
+ * Create a new public key from a secret key.
+ **/
 int
 cdk_pk_from_secret_key( cdkPKT_secret_key * sk, cdkPKT_public_key ** ret_pk )
 {
@@ -840,7 +847,68 @@ cdk_pk_from_secret_key( cdkPKT_secret_key * sk, cdkPKT_public_key ** ret_pk )
         return CDK_Inv_Value;
     return _cdk_copy_pubkey( ret_pk, sk->pk );
 }
+
+
+int
+cdk_pk_revoke_import( CDK_KEYDB_HD db, const char * revcert )
+{
+    /* due to the fact the keydb code can't insert or modify packets
+       it is not possible to handle this step yet */
+    return 0;
+}
+
+
+int
+cdk_pk_revoke_create( cdkPKT_secret_key * sk, int code, const char * inf,
+                      char ** ret_revcert )
+{
+    GCRY_MD_HD md;
+    cdkPKT_signature * sig;
+    CDK_SUBPKT node;
+    char * p = NULL, * dat;
+    int n;
     
+    if( !sk || !ret_revcert )
+        return CDK_Inv_Value;
+    if( code < 0 || code > 3 )
+        return CDK_Inv_Value;
+
+    sig = cdk_calloc( 1, sizeof * sig );
+    if( !sig )
+        return CDK_Out_Of_Core;
+    _cdk_sig_create( sk->pk, sig );
+    n = 1;
+    if( inf ) {
+        n += strlen( p );
+        p = cdk_utf8_encode( inf );
+    }
+    dat = cdk_calloc( 1, n+1 );
+    if( !dat ) {
+        _cdk_free_signature( sig );
+        return CDK_Out_Of_Core;
+    }
+    dat[0] = code;
+    if( inf )
+        memcpy( dat+1, p, strlen( p ) );
+    cdk_free( p );
+
+    node = cdk_subpkt_new( n );
+    if( node ) {
+        _cdk_subpkt_init( node, SIGSUBPKT_REVOC_REASON, dat, n );
+        _cdk_subpkt_add( sig->hashed, node );
+    }
+    cdk_free( dat );
+
+    md = gcry_md_open( GCRY_MD_SHA1, 0 );
+    if( !md ) {
+        _cdk_free_signature( sig );
+        return CDK_Gcry_Error;
+    }
+    _cdk_hash_pubkey( sk->pk, md, 1 );
+    _cdk_free_signature( sig );
+    return 0;
+}
+
 
 int
 _cdk_sk_get_csum( cdkPKT_secret_key * sk )
@@ -868,14 +936,14 @@ cdk_pk_get_fingerprint( cdkPKT_public_key * pk, byte * fpr )
     if( pk->version < 4 && is_RSA( pk->pubkey_algo ) )
         md_algo = GCRY_MD_MD5; /* special */
     else
-        md_algo = pk->version < 4 ? GCRY_MD_RMD160 : GCRY_MD_SHA1;
+        md_algo = pk->version < 4 ? CDK_MD_RMD160 : CDK_MD_SHA1;
     dlen = gcry_md_get_algo_dlen( md_algo );
     hd = gcry_md_open( md_algo, 0 );
     if( !hd )
         return CDK_Gcry_Error;
     _cdk_hash_pubkey( pk, hd, 1 );
     gcry_md_final( hd );
-    memcpy( fpr, gcry_md_read( hd, md_algo), dlen );
+    memcpy( fpr, gcry_md_read( hd, md_algo ), dlen );
     gcry_md_close( hd );
     if( dlen == 16 )
         memset( fpr + 16, 0, 4 );
@@ -989,7 +1057,7 @@ _cdk_pkt_get_keyid( CDK_PACKET * pkt, u32 * keyid )
 
 
 int
-_cdk_fingerprint_get( CDK_PACKET * pkt, byte * fpr )
+_cdk_pkt_get_fingerprint( CDK_PACKET * pkt, byte * fpr )
 {
     if( !pkt || !fpr )
         return CDK_Inv_Value;
