@@ -39,10 +39,6 @@
 # define HAVE_U32_TYPEDEF
 #endif
 
-#ifndef HAVE_SNPRINTF
-int snprintf (char *str, size_t count, const char *fmt, ...);
-#endif
-
 #ifndef DIM
 # define DIM(v) (sizeof (v)/sizeof ((v)[0]))
 # define DIMof(type, member)   DIM(((type *)0)->member)
